@@ -7,12 +7,10 @@ sys.path.insert(0, parent)
 
 os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.test_settings'
 
-from django.test.utils import get_runner
-from django.conf import settings
+from django.test.simple import run_tests
 
 def runtests():
-    test_runner = get_runner(settings)
-    failures = test_runner([], verbosity=1, interactive=True)
+    failures = run_tests(['tests'], verbosity=1, interactive=True)
     sys.exit(failures)
 
 if __name__ == '__main__':
